@@ -156,8 +156,8 @@ class DwdWeatherWarningsAPI:
 
         Parameters
         ----------
-        identifier : str or int
-            a valid warncell id or name
+        identifier : str, int or tuple
+            a valid warncell id, name or location (latitude, longitude)
             https://www.dwd.de/DE/leistungen/opendata/help/warnungen/
                     cap_warncellids_csv.html
             NOTE: Some of the warncells are outdated but still listed.
@@ -175,7 +175,10 @@ class DwdWeatherWarningsAPI:
         self.expected_warnings = None
 
         # Identifier must be either integer or string
-        if not isinstance(identifier, (int, str)):
+        if not isinstance(identifier, (int, str, tuple)):
+            return
+        # Tuple version must consist of 2 values (latitude and longitude)
+        elif isinstance(identifier, tuple) and len(identifier) != 2:
             return
 
         self.__generate_query(identifier)
@@ -230,30 +233,46 @@ class DwdWeatherWarningsAPI:
             "dwd:Warngebiete_Kueste": "dwd:Warnungen_Kueste",
         }
 
-        identifier = str(identifier)
         region_query = {}
+        # Numbers represent warncell ids
+        if isinstance(identifier, int) or (isinstance(identifier, str) and identifier.isnumeric()):
+            region_query["CQL_FILTER"] = f"WARNCELLID='{identifier}'"
+        # Strings represent warncell names
+        elif isinstance(identifier, str):
+            region_query["CQL_FILTER"] = f"NAME='{identifier}'"
+        # Tuples represent gps locations (latitude, longitude)
+        elif isinstance(identifier, tuple):
+            region_query["CQL_FILTER"] = f"CONTAINS(SHAPE, Point({identifier[0]} {identifier[1]}))"
 
-        found_cnt = 0
         for region in weather_warnings_query_mapping:
             region_query["typeName"] = region
             result = query_dwd(**region_query)
             if result is not None:
-                for res in result["features"]:
-                    if (identifier in res["id"]) or (
-                        identifier == res["properties"]["NAME"]
-                    ):
-                        cell_id = res["id"][res["id"].rfind(".") + 1 :]
-                        if cell_id.isnumeric():
-                            self.warncell_id = int(cell_id)
-                            self.warncell_name = res["properties"]["NAME"]
-                            self.__query = {
-                                "typeName": weather_warnings_query_mapping[
-                                    region
-                                ]
-                            }
-                            found_cnt += 1
-        if found_cnt > 1:
-            self.warncell_name += " (not unique used ID)!"
+                if result["numberReturned"] > 0:
+                    self.warncell_id = result["features"][0]["properties"][
+                        "WARNCELLID"
+                    ]
+                    self.warncell_name = result["features"][0]["properties"][
+                        "NAME"
+                    ]
+                    # More than one match found. Can only happen if search is
+                    # done by name.
+                    if result["numberReturned"] > 1:
+                        self.warncell_name += " (not unique used ID)!"
+
+                    self.__query = {
+                        "typeName": weather_warnings_query_mapping[region]
+                    }
+                    # Special handling for counties
+                    if region == "dwd:Warngebiete_Kreise":
+                        self.__query[
+                            "CQL_FILTER"
+                        ] = f"GC_WARNCELLID='{self.warncell_id}'"
+                    else:
+                        self.__query[
+                            "CQL_FILTER"
+                        ] = f"WARNCELLID='{self.warncell_id}'"
+                    break
 
     def __parse_result(self, json_obj):
         """Parse the retrieved data."""
@@ -277,19 +296,18 @@ class DwdWeatherWarningsAPI:
 
             if json_obj["numberReturned"]:
                 for feature in json_obj["features"]:
-                    if str(self.warncell_id) in feature["id"]:
-                        warning = convert_warning_data(feature["properties"])
+                    warning = convert_warning_data(feature["properties"])
 
-                        if warning["urgency"] == "immediate":
-                            current_warnings.append(warning)
-                            current_maxlevel = max(
-                                warning["level"], current_maxlevel
-                            )
-                        else:
-                            expected_warnings.append(warning)
-                            expected_maxlevel = max(
-                                warning["level"], expected_maxlevel
-                            )
+                    if warning["urgency"] == "immediate":
+                        current_warnings.append(warning)
+                        current_maxlevel = max(
+                            warning["level"], current_maxlevel
+                        )
+                    else:
+                        expected_warnings.append(warning)
+                        expected_maxlevel = max(
+                            warning["level"], expected_maxlevel
+                        )
 
             self.current_warning_level = current_maxlevel
             self.current_warnings = current_warnings
